@@ -7,8 +7,7 @@ Basic error classes and their descriptors
 
 
 class UserErrorHandle():
-  """
-  Class that handles errors the user can identify / recover from
+  """Class that handles errors the user can identify / recover from
   """
 
   def __init__(self, msg, *msgs, **extra):
@@ -19,9 +18,8 @@ class UserErrorHandle():
     return f"{self.msg}\n" + "\n".join(f"{k}: {v}" for k, v in self.extras.items())
 
 
-class CustomError(Exception):
-  """
-  Exception class that is root of all custom exceptions
+class Error(Exception):
+  """Exception class that is root of all custom exceptions
   """
 
   def __init__(self, msg, *msgs, **extra):
@@ -32,15 +30,13 @@ class CustomError(Exception):
     return f"{self.msg}\n" + "\n".join(f"{k}: {v}" for k, v in self.extras.items())
 
 
-class ProgrammerError(CustomError):
-  """
-  Exception class that is root of all programmer related exceptions
+class ProgrammerError(Error):
+  """Exception class that is root of all internal / implementation / programmer related errors
   """
   ...
 
 
 class InappropriateRequest(ProgrammerError):
-  """
-  Exception class that is raised when a request on some programming object / function / property is inappropriate
+  """Exception class that is raised when a request on some programming object / function / property is inappropriate
   """
   ...
