@@ -1,11 +1,13 @@
+from .coms import Communicator
+comm = Communicator()
 import time
 import discord
 
-intents = discord.Intents.all()
-#intents.message_content = True
+intents = discord.Intents.default()
+intents.message_content = True
 
 client = discord.Client(intents=intents)
-TOKEN = "OTU5MjYzNzU3NjczMDY2NTA2.YkZV_g.cuMAZc-BAK7lHWxkrZlWgT2LWeI"
+TOKEN = comm.requestSecret("ryanpinger TOKEN")
 
 
 @client.event
